==> simplepycons-1!13.14.1-py3-none-any.whl: simplepycons/_virtualbox.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (c) 2024 Carsten Igel.
#
# This file is part of simplepycons
# (see https://github.com/carstencodes/simplepycons).
#
# This file is published using the MIT license.
# Refer to LICENSE for more information
#
""""""
# pylint: disable=C0302
# Justification: Code is generated

from typing import TYPE_CHECKING

from .base_icon import Icon

if TYPE_CHECKING:
    from collections.abc import Iterable


class VirtualboxIcon(Icon):
    """"""
    @property
    def name(self) -> "str":
        return "virtualbox"

    @property
    def original_file_name(self) -> "str":
        return "virtualbox.svg"

    @property
    def title(self) -> "str":
        return "VirtualBox"

    @property
    def primary_color(self) -> "str":
        return "#183A61"

    @property
    def raw_svg(self) -> "str":
        return ''' <svg xmlns="http://www.w3.org/2000/svg"
 role="img" viewBox="0 0 24 24">
    <title>VirtualBox</title>
     <path d="M12 0a.477.477 0 0 0-.188.047L2.17
 4.274c-.265.169-.378.363-.372.692l.832
 10.278c.009.107.047.165.128.25l3.564 2.713s.015 2.015.455 2.806C7.109
 21.61 8.652 24.033 12 24c3.348-.033 4.988-2.03
 5.484-3.028.47-.946.46-2.912.46-2.912l3.255-2.548a.31.31 0 0 0
 .14-.258l.86-10.31c.026-.312-.103-.57-.368-.685L12.181.047A.435.435 0
 0 0 12 0zm-.051 1.078c.054.002.108.02.188.056l7.417 3.429L12.132
 8.9c-.115.058-.166.049-.264 0l-7.35-4.264c-.113-.074-.12-.125
 0-.197l7.234-3.314a.534.534 0 0 1 .197-.047zm.01.688L5.905
 4.591l6.042 3.49 6.067-3.48zm0 .375l5.232 2.46-3.262 1.82-1.04-.557
 1.764-2.208-2.138.838L13.639 3.1l-3.252 1.346
 1.1-1.15-.978-.45zm-1.837.849l.784.388-2.115 2.098 3.615-1.492-1.246
 1.502 2.237-.932-1.136 1.419 1.232.666-1.56.885-5.148-2.946zm-6.93
 3.902c.029 0 .072.02.135.054l7.28 4.577.017
 7.818-6.853-5.057c-.077-.073-.104-.098-.103-.193l-.52-7.137c0-.043.015-.062.044-.062zm17.592.086c.03
 0 .042.02.043.062l-.495 7.027c0 .096-.026.12-.103.193l-6.843
 5.081.043-7.805 7.219-4.504a.348.348 0 0 1 .136-.054zm-.805
 3.206l-.177.126-.133.442-.049-.315-.226.15.145.598-.224.915.233-.195.085-.527.064.413.278-.184-.195-.682zm-15.71.249c-.12-.011-.19.127-.169.37.028.327.21.72.408.877l.419.33c.2.158.338.018.307-.313-.03-.33-.216-.724-.414-.879l-.417-.323a.265.265
 0 0 0-.134-.062zm.075.235a.173.173 0 0 1
 .087.041l.397.31c.129.101.25.358.27.57.02.215-.07.304-.199.202l-.4-.315c-.128-.101-.246-.354-.264-.566-.014-.158.03-.249.109-.242zm14.823.103c0-.035-.074.01-.115.04-.16.123-.358.559-.372
 1.068-.015.556.11.619.263.514.162-.11.382-.492.39-1.026.007-.409-.166-.491-.166-.596zm-.713.067s-.439.19-.44.295c-.01.65-.07
 1.968-.07
 1.968l.332-.251s.329-.218.334-.82c.003-.386-.126-.31-.126-.31s.104-.218.106-.514c.005-.445-.136-.368-.136-.368zm.602.214c.115
 0
 .094.268.092.446-.002.175-.088.576-.18.643-.093.068-.1-.243-.098-.423.003-.173.074-.666.186-.666zm-.72.075s.08-.05.073.214a.829.829
 0 0 1-.088.328l-.134.09.006-.538zm-.512.021l-.229.14-.06
 1.843s-.014.184.036.222c.072.056.267-.173.267-.173l-.004-.21s-.075.018-.072-.058zM5.25
 11.16l.112 1.196.14.111-.091-.988.461.363a.47.47 0 0 1
 .137.287c.01.108-.033.154-.098.103l-.396-.313.477.936.205.163-.32-.617.063.05c.137.107.23.013.208-.213-.022-.225-.15-.496-.287-.602zm13.049.78s.1-.024.09.279c-.008.257-.09.338-.09.338l-.152.11.013-.62zm-.95.174c-.042-.012-.102.006-.189.077-.107.07-.305.38-.305.38l.008.19s.114-.141.171-.187c.221-.22.165.09.165.09l-.005.099-.156.146s-.231.227-.243.658c-.006.206.068.35.18.265.11-.082.247-.33.247-.33l.004.144.19-.17.013-1.02s.043-.307-.08-.342zm-10.704.126c-.035-.028-.066-.027-.08.004l-.334.8.167.133.273-.671.254.69-.38-.3.105.28.386.307.103.28.17.134-.572-1.518a.338.338
 0 0 0-.092-.139zm10.054.35l-.18.132-.01
 1.078s-.098.19-.14.217c-.072.047-.07-.107-.07-.107l.015-1.02-.192.145-.015
 1.02s-.011.457.182.313a.779.779 0 0 0
 .222-.323l.017.128.154-.11zm-.806.11l-.164.108-.066.489-.077.049v.023l-.152.095c-.06.093-.098.38-.098.38l.002-.288-.175.124-.04
 1.483.198-.143.043-.877s.032-.211.098-.321l.107-.086.017-.309.002.155.066-.056-.008.945s-.015.314.15.204c.057-.039.213-.23.213-.23L16
 14.252s-.076.071-.1.086c-.037.023-.036-.058-.036-.058l.021-.915.11-.077-.003-.24-.096.06zm-8.551.14c-.124-.012-.197.13-.171.384.035.339.232.748.44.913l.449.353.062-.15-.524-.415c-.134-.107-.263-.37-.286-.59-.023-.219.07-.31.203-.206l.423.333.062-.15-.517-.408a.28.28
 0 0
 0-.141-.064zm9.85.172v.357s-.107.126-.156.155c-.048.029-.06-.055-.06-.129a.457.457
 0 0 1 .118-.293zm-2.226.171c-.067.048-.123.188-.124.313 0
 .125.053.187.12.14.068-.048.125-.188.126-.314
 0-.125-.054-.188-.122-.139zm-6.887.189l.12 1.12a.296.296 0 0 0
 .087.178l.673.532.062-.152-.686-.543-.11-1.022zm6.684.109l-.213.156s-.022.371-.182
 1.69c-.132-.98-.132-1.45-.132-1.45l-.246.163.152
 1.803.365-.208zm.259.298l-.197.141-.062
 1.505.197-.142zm-5.911.446c-.127-.013-.198.133-.169.392.039.346.244.765.457.934l.46.364.064-.154-.541-.426c-.114-.09-.225-.29-.273-.485l.636.5.062-.153-.724-.57c.01-.146.094-.196.207-.107l.436.343.062-.152-.534-.418a.292.292
 0 0 0-.143-.068zm.769.587c-.013.013-.02.042-.015.081a.351.351 0 0 0
 .105.21c.048.038.08.006.07-.073a.36.36 0 0
 0-.105-.212c-.024-.018-.042-.02-.055-.006zm.015.032c.01-.01.026-.01.045.004.038.03.074.104.08.165.008.063-.016.088-.055.058-.012-.01-.015-.035-.025-.051l.006.004-.006-.06.015.01.025.078.022.017-.03-.084h.004c.008-.002.009-.013.008-.019v-.013a.122.122
 0 0 0-.025-.058.12.12 0 0
 0-.026-.025l-.023-.02.015.137c-.015-.03-.037-.05-.04-.08-.005-.032
 0-.053.01-.063zm.036.047l.006.004c.01.008.013.011.018.017a.07.07 0 0
 1 .01.026c0 .006.002.01 0
 .013-.002.006-.009.002-.015-.002l-.013-.01z" />
</svg>'''

    @property
    def guidelines_url(self) -> "str | None":
        _value: "str" = ''''''
        if len(_value) > 0:
            return _value
        return None

    @property
    def source(self) -> "str":
        return '''https://commons.wikimedia.org/wiki/File:Virtu'''

    @property
    def license(self) -> "tuple[str | None, str | None]":
        _type: "str | None" = ''''''
        _url: "str | None" = ''''''

        if _type is not None and len(_type) == 0:
            _type = None

        if _url is not None and len(_url) == 0:
            _url = None

        return _type, _url

    @property
    def aliases(self) -> "Iterable[str]":
        yield from []

==> simplepycons-1!14.0.1-py3-none-any.whl: simplepycons/_virtualbox.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (c) 2024 Carsten Igel.
#
# This file is part of simplepycons
# (see https://github.com/carstencodes/simplepycons).
#
# This file is published using the MIT license.
# Refer to LICENSE for more information
#
""""""
# pylint: disable=C0302
# Justification: Code is generated

from typing import TYPE_CHECKING

from .base_icon import Icon

if TYPE_CHECKING:
    from collections.abc import Iterable


class VirtualboxIcon(Icon):
    """"""
    @property
    def name(self) -> "str":
        return "virtualbox"

    @property
    def original_file_name(self) -> "str":
        return "virtualbox.svg"

    @property
    def title(self) -> "str":
        return "VirtualBox"

    @property
    def primary_color(self) -> "str":
        return "#2F61B4"

    @property
    def raw_svg(self) -> "str":
        return ''' <svg xmlns="http://www.w3.org/2000/svg"
 role="img" viewBox="0 0 24 24">
    <title>VirtualBox</title>
     <path d="M0 1.758 5.182
 20c.129.455.25.691.421.945.063.092.13.179.202.264.173.204.37.378.59.525.243.163.49.286.763.371.324.1.61.137.99.137h4.327l1.918-6.615h6.798v3.699a.11.11
 0 0 1-.109.11h-4.88l-.813 2.806h5.654a2.92 2.92 0 0 0 1.95-.725A2.903
 2.903 0 0 0 24 19.285v-6.47H12.28l-1.919 6.614H7.937L3.715
 4.564h2.922l1.546 5.444H11.1l-2.343-8.25zm15.496 0-2.4
 8.25H24v-5.29a2.962 2.962 0 0 0-1.825-2.741 3.044 3.044 0 0
 0-1.129-.22zm2.11 2.806h3.476a.11.11 0 0 1 .11.112V7.2h-4.354z" />
</svg>'''

    @property
    def guidelines_url(self) -> "str | None":
        _value: "str" = ''''''
        if len(_value) > 0:
            return _value
        return None

    @property
    def source(self) -> "str":
        return '''https://www.virtualbox.org/svn/vbox/trunk/src'''

    @property
    def license(self) -> "tuple[str | None, str | None]":
        _type: "str | None" = ''''''
        _url: "str | None" = ''''''

        if _type is not None and len(_type) == 0:
            _type = None

        if _url is not None and len(_url) == 0:
            _url = None

        return _type, _url

    @property
    def aliases(self) -> "Iterable[str]":
        yield from [
            "Oracle VirtualBox",
        ]
